@@ -12,7 +12,7 @@ try:
 except:
     pass
 
-version = '0.121'
+version = '0.122'
 
 import re
 import tempfile
@@ -837,7 +837,7 @@ def imsread(paths):
     assert isinstance(paths, list) or isinstance(paths, tuple), type(paths)
     return [imread(path) for path in paths]
 
-def imwrite(path=None, img=None, jpeg_quality=95, print_assumptions=True):
+def imwrite(path=None, img=None, jpeg_quality=95, print_assumptions=True, atomic=False):
     if path is None:
         path = "./imwrite_out.png"
         if print_assumptions:
@@ -858,10 +858,17 @@ def imwrite(path=None, img=None, jpeg_quality=95, print_assumptions=True):
     path = os.path.expanduser(path)
     os.makedirs(os.path.dirname(path), exist_ok=True)
     
+    if atomic:
+        path_final = path
+        path = path.replace('.', '_tmp.')
+    
     if path[-4:] == '.jpg' or path[-4:] == '.jpeg':
         cv2.imwrite(path, img[:, :, [2, 1, 0]], [int(cv2.IMWRITE_JPEG_QUALITY), jpeg_quality])
     else:
         cv2.imwrite(path, img[:, :, [2, 1, 0]])
+        
+    if atomic:
+        os.rename(path, path_final)
 
 def imjoin(imgs, axis=1, pad=0):
     if pad > 0:
@@ -1079,7 +1086,7 @@ if is_testing(): imshow(imAddNoiseGauss(imNewWhite(150, 150), 30))
 
 
 if is_testing():
-    imwrite('/tmp/img.jpg', imscaleNN(imNewNoise(100, 100), 2), jpeg_quality=1)
+    imwrite('/tmp/img.jpg', imscaleNN(imNewNoise(100, 100), 2), jpeg_quality=1, atomic=True)
     imshow('/tmp/img.jpg')
 
 
